#include <stdio.h>
#include <stdlib.h>
#include "mysql.h"
#include <stdarg.h>
#include <time.h>
#include <string.h>

#define MAX_QUERY_LEN 256

char query[MAX_QUERY_LEN];

int max_id = 1000000;
int query_cnt = 100000;

MYSQL *mysql;
MYSQL_RES *result;
MYSQL_ROW record;

void test_client_multi_statement()
{
  int i, id;
  mysql = mysql_init(NULL);
  if (!mysql_real_connect(mysql, NULL, "root", NULL, "test", 3306,
                          "/u01/mysql/run/mysql.sock",
                          CLIENT_MULTI_STATEMENTS))
  {
    printf("mysql_real_connect failed: in test_client_multi_statement\n");
    mysql_close(mysql);
    exit(1);
  }

  time_t start = time(NULL);

  i = query_cnt;
  while (i--)
  {
    id= rand() % max_id;
    memset(query, 0, MAX_QUERY_LEN);
    sprintf(query, "update t set num=num+1 where id=%d;"
            " select num from t where id=%d;", id, id);
    if (mysql_query(mysql, query))
    {
      printf("execute '%s' failed in test_client_multi_statement: %s\n",
             query, mysql_error(mysql));
      mysql_close(mysql);
      exit(1);
    }
    do
    {
      mysql_free_result(mysql_store_result(mysql));
    } while (!mysql_next_result(mysql));
  }
 
  time_t end = time(NULL);

  printf("test_client_multi_statement: %d seconds\n", end - start);
  mysql_close(mysql);
}

void test_get_update()
{
  int i, id;
  mysql = mysql_init(NULL);
  if (!mysql_real_connect(mysql, NULL, "root", NULL, "test", 3306,
                          "/u01/mysql/run/mysql.sock",0))
  {
    printf("mysql_real_connect failed: in test_get_update\n");
    mysql_close(mysql);
    exit(1);
  }

  time_t start = time(NULL);
  i = query_cnt;
  while (i--)
  {
    id= rand() % max_id;
    memset(query, 0, MAX_QUERY_LEN);
    sprintf(query, "get num from update t set num=num+1 where id=%d;", id);
    if (mysql_query(mysql, query))
    {
      printf("execute '%s' failed in test_get_update: %s\n",
             query, mysql_error(mysql));
      mysql_close(mysql);
      exit(1);
    }
    mysql_free_result(mysql_store_result(mysql));
  }
  time_t end = time(NULL);

  printf("test_get_update: %d seconds\n", end - start);
  mysql_close(mysql);
}

int main()
{
  srand((unsigned int)time(0));

  test_client_multi_statement();
  test_get_update();

  return 0;
}